==> fourthdimension-2.0.6.tar.gz: fourthdimension-2.0.6/setup.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()


setuptools.setup(
    name="fourthdimension",
    version="2.0.6",
    author="ytkj",
    author_email="lijinxin@yantu-ai.com",
    install_requires=["httpx==0.27.0","pydantic","pandas","pyjwt","pydantic-core","cachetools","networkx"],
    include_package_data=True,
    description="fourthdimension",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/hustai/FourthDimension",
    packages=setuptools.find_packages(where="src", exclude=["tests"]),
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)

==> fourthdimension-2.0.7.tar.gz: fourthdimension-2.0.7/setup.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="fourthdimension",
    version="2.0.7",
    author="ytkj",
    author_email="lijinxin@yantu-ai.com",
    install_requires=["httpx==0.27.0", "pydantic", "pandas", "pyjwt", "pydantic-core", "cachetools", "networkx",
                      "termcolor"],
    include_package_data=True,
    description="fourthdimension",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitee.com/hustai/FourthDimension",
    packages=setuptools.find_packages(where="src", exclude=["tests"]),
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)
